@@ -10,7 +10,7 @@ class TextGenerationCallback(TrainerCallback):
     sense of different checkpoints.
     """
 
-    def __init__(self, prompts, out_dir, **generate_kwargs):
+    def __init__(self, model, tokenizer, prompts, out_dir, **generate_kwargs):
         """
         Parameters
         ----------
@@ -18,6 +18,8 @@ class TextGenerationCallback(TrainerCallback):
         path: str or Path
         generate_kwargs: any
         """
+        self.model = model
+        self.tokenizer = tokenizer
         self.prompts = list(prompts)
         self.out_dir = out_dir
         self.out_path = Path(out_dir)/'generated_text_samples.txt'
@@ -32,4 +34,4 @@ class TextGenerationCallback(TrainerCallback):
             f.write(self.header_fmt.format(sep=self.sep,
                                            global_step=state.global_step))
         for prompt in self.prompts:
-            self.generate_fn(kwargs['model'], kwargs['tokenizer'], prompt)
\ No newline at end of file
+            self.generate_fn(self.model, self.tokenizer, prompt)
\ No newline at end of file
